package ch.sahits.game.graphic.image;

import java.awt.Font;
import java.awt.FontFormatException;
import java.io.IOException;
/**
 * Interface for loading defined fonts
 * @author Andi Hotz, (c) Sahits GmbH, 2012
 * Created on Jun 29, 2012
 *
 */
public interface IFontLoader {

	/**
	 * Load a gothic font, a fraktur font.
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createGothicFont() throws FontFormatException,
			IOException;

	/**
	 * Create the default font for all texts
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createStarnbergFont() throws FontFormatException,
			IOException;

	/**
	 * Create the default font for all texts
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createDefaultFont() throws FontFormatException,
			IOException;

	/**
	 * Create the default font at a given font size
	 * @param size
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createDefaultFont(int size)
			throws FontFormatException, IOException;

	/**
	 * Create the default font at a given font size
	 * @param size
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createStranbergFont(int size)
			throws FontFormatException, IOException;

	/**
	 * Create a hand written font.
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public abstract Font createDefaultHandwrittenFont()
			throws FontFormatException, IOException;
	/**
	 * Retrieve the default decorative font
	 * @return
	 * @throws FontFormatException
	 * @throws IOException
	 */
	public Font createDefaultDecorativeFont() throws FontFormatException, IOException;

}