package ch.sahits.game.graphic.image;

import java.awt.image.BufferedImage;
/**
 * Interface defining the functionality for loading images. The implementation
 * provides caching of loaded images
 * @author aho
 *
 */
public interface IImageLoader {

	/**
	 * Replace a single image entry with another image
	 * @param name under which the image is stored
	 * @param img Image that replaces the old one.
	 * @return false if img is null
	 */
	public boolean replaceSingleImage(String name, BufferedImage img);

	/**
	 * Get the image associated with <name>. If there are several images stored
	 * under that name, return the first one in the list.
	 */
	public BufferedImage getImage(String name); // end of getImage() with name input;

	/**
	 * Get the image associated with &lt;name&gt; at position &lt;posn&gt; in its list. If
	 * &lt;posn&gt; is < 0 then return the first image in the list. If posn is bigger
	 * than the list's size, then calculate its value modulo the size.
	 */
	public BufferedImage getImage(String name, int posn); // end of getImage() with posn input;
	/**
	 * Check if the file is already loaded into the internal cache
	 * @param name of the file to be loaded
	 * @return
	 */
	public boolean isLoaded(String name); // end of isLoaded()
	/**
	 * Check how many images are stored under <code>name</code> 
	 * @param name
	 * @return
	 */
	public int numImages(String name); // end of numImages()

	/**
	 * Load the image from <fnm>, returning it as a BufferedImage which is
	 * compatible with the graphics device being used. Uses ImageIO.
	 */
	public BufferedImage loadImage(String fnm); // end of loadImage() using ImageIO

}