package ch.sahits.game.graphic.image;

import java.awt.Point;

/**
 * Define the functionality to calculate the offset to absolute coordinates on screen
 * @author Andi Hotz, (c) Sahits GmbH, 2012
 * Created on Jun 29, 2012
 *
 */
public interface IOffsetCalculator {

	/**
	 * Compute the absolute offset of the point X
	 * @param relativeXOffset relative offset (in relation to the image) of X
	 * @return absolute offset of X
	 */
	public int computeXOffset(int relativeXOffset);

	/**
	 * Compute the absolute offset of the point Y
	 * @param relativeYOffset relative offset (in relation to the image) of Y
	 * @return absolute offset of Y
	 */
	public int computeYOffset(int relativeYOffset);

//	/**
//	 * Compute the absolute offset of the point X in the case that the relative offset
//	 * is scaled dynamically
//	 * @param relativeXOffset relative offset (in relation to the image) of X
//	 * @return absolute offset of X
//	 */
//	public int computeXOffset(int relativeXOffset, double xScale);
//
//	/**
//	 * Compute the absolute offset of the point Y in the case that the relative offset
//	 * is scaled dynamically
//	 * @param relativeYOffset relative offset (in relation to the image) of Y
//	 * @return absolute offset of Y
//	 */
//	public int computeYOffset(int relativeYOffset, double yScale);

	/**
	 * Compute the absolute offset of the point
	 * @param relativeYOffset relative offset (in relation to the image) of Y
	 * @param relativeYOffset relative offset (in relation to the image) of Y
	 * @return absolute offset
	 */
	public Point computeOffset(int relativeXOffset, int relativeYOffset);

}