package ch.sahits.game.graphic.image;

import java.awt.Font;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
/**
 * OpenPatrician painter that specialized on painting stone slabs of various sizes.
 * @author Andi Hotz, (c) Sahits GmbH, 2012
 * Created on Jun 29, 2012
 *
 */
public interface IOpenPatricianSlabPainter extends IOpenPatricianPainter{

	/**
	 * Paint a button.
	 *
	 * @param graphics The graphics object to be used for painting.
	 * @param button The button to paint
	 */
	public void paintButton(Graphics graphics, Rectangle bounds);

	/**
	 * Paint a button.
	 *
	 * @param graphics The graphics object to be used for painting.
	 * @param button The button to paint
	 */
	public BufferedImage createButton(Graphics graphics, String text,
			Rectangle bounds);

	/**
	 * Create an image of a scaled plank
	 * @param width destination width
	 * @param height destination height
	 * @return
	 */
	public BufferedImage createScaledPlank(int width, int height);

	/**
	 * create the check box image
	 * @return
	 */
	public BufferedImage createCheckBoxImage();

	/**
	 * create the check box image
	 * @return
	 */
	public BufferedImage createRadioButtonImage();

	/**
	 * Create an image of the specified size and draw a String on it.
	 * This method makes sure that the whole string is drawn over a stone slab
	 * instead of on the brickwork.
	 * @param s String to be printed
	 * @param f Font to be used for the drawing
	 * @param imgWidth Width of the image that is augmented
	 * @param compWidth width of the component
	 * @param compHeigh height of the component
	 * @return
	 */
	public BufferedImage createTextOnSlab4ToggleButton(String s,
			Font f, int imgWidth, int compWidth, int compHeigh);

}