package ch.sahits.game.graphic.image;
import java.awt.Point;

import ch.sahits.game.graphic.image.model.ImageData;
import ch.sahits.game.graphic.image.model.NamedPolygon;
import ch.sahits.game.image.ImageScaleState;

/**
 * This interface defines the functionality that is needed to manipulate polygons, that define clickable
 * areas within an image. As the image is cropped, scaled and bordered this influences the locations and size
 * of the defined polygons. Furthermore there is the issue, That the polygons are defined relative to the top left
 * corner of the image, for usage the absolute coordinates on the screen are needed.
 * @author Andi Hotz, (c) Sahits GmbH, 2012
 * Created on Jun 29, 2012
 *
 */
public interface IPolygonScaling {
	/**
	 * Compute the location and dimensions of the {@link NamedPolygon}s that are contained in
	 * <code>imgData</code> based on the scaling state. If the image was cropped or bordered this
	 * may result in a translocation of the defined polygon. If the image was scaled this will result
	 * in a translocation to or from the origin (top left corner) by the factor of the scaling.
	 * A new instance of image Data with the new polygon definition will be returned.
	 * @param imgData Input data of the image containing a list of {@link NamedPolygon}s that are to be recalculated
	 * @param state of the scaled image
	 * @return new instance of ImageData containing the recalculated polygons
	 */
	public ImageData recalculatePolygons(ImageData imgData, ImageScaleState state);
	/**
	 * Recalculate the positions of the polygons to reflect their absolute on screen locations.
	 * @param imgData Input data of the image containing a list of {@link NamedPolygon}s that are to be recalculated
	 * @param offset Point indicating the absolute position on screen of the origin (top left corner) of the image
	 * @return new instance of ImageData containing the recalculated polygons
	 */
	public ImageData recalculatePolygonsOffsett(ImageData imgData, Point offset);
}
