package ch.sahits.game.graphic.image;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import ch.sahits.game.image.IImageUtilities;
import ch.sahits.game.openpatrician.model.ModelDIFactory;

public class ImageDIResolver extends ModelDIFactory {
	
	private BeanFactory factory;
	
	private static ImageDIResolver INSTANCE=null;
	/**
	 * Make the constructor portected to ensure it only can be called from super classes
	 * implementing the singleton pattern
	 */
	protected ImageDIResolver(){
		super();
	}
	public static ImageDIResolver getInstance(){
		if (INSTANCE==null){
			INSTANCE=new ImageDIResolver();
		}
		return INSTANCE;
	}

	@Override
	public void init() {
		super.init();
		factory = new ClassPathXmlApplicationContext("springContext.xml");

	}
	
	public IImageLoader getIndividualImageLoader(){
		return (IImageLoader) factory.getBean("individualImageLoader");
	}
	/**
	 * Retrieve the image utility instance
	 * @return
	 */
	public IImageUtilities getImageUtilities(){
		return (IImageUtilities) factory.getBean("imageUtilities");
	}
	/**
	 * Retrieve the font loader 
	 * @return
	 */
	public IFontLoader getFontLoader(){
		return (IFontLoader) factory.getBean("fontLoader");
	}
	/**
	 * Retrieve the offset calculator for the specified offset
	 * @param xOffset
	 * @param yOffset
	 * @return
	 */
	public IOffsetCalculator getOffsetcalculator(int xOffset, int yOffset){
		return (IOffsetCalculator) factory.getBean("offsetCalculator", new Object[]{xOffset,yOffset});
	}
	/**
	 * Retrieve the polygon calculator bean
	 * @return
	 */
	public IPolygonScaling getPolygonCalculator(){
		return (IPolygonScaling) factory.getBean("polygonCalculator");
	}
	/**
	 * Retrieve the instance for the open patrician painter
	 * @return
	 */
	public IOpenPatricianPainter getOpenPatricianPainter(){
		return (IOpenPatricianPainter) factory.getBean("opPainter");
	}

	/**
	 * Retrive the instance for the open patrician slab painter
	 * @return
	 */
	public IOpenPatricianSlabPainter getOpenPatricianSlabPainter(){
		return (IOpenPatricianSlabPainter) factory.getBean("opSlabPainter");
	}

}
