package ch.sahits.game.graphic.image.model;

import java.util.Map;
import java.util.Map.Entry;
import java.util.TreeMap;

import ch.sahits.game.image.ECrop;
/**
 * Representing of image data
 * @author aho
 *
 */
public class ImageData implements Cloneable{
	/** Map holding all the polygons in theri correct z-order */
	private final Map<Integer,NamedPolygon> polygons;
	private final String imageName;
	private final ECrop crop;
	private final int maxCrop;
	public ImageData(String imageName, ECrop crop,
			int maxCrop) {
		super();
		this.polygons = new TreeMap<Integer, NamedPolygon>();
		this.imageName = imageName;
		this.crop = crop;
		this.maxCrop = maxCrop;
	}
	public void addPolygon(NamedPolygon polygon, int zIndex){
		polygons.put(zIndex,polygon);
	}
	public Map<Integer,NamedPolygon> getPolygons(){
		return polygons;
	}
	public String getImageName() {
		return imageName;
	}
	public ECrop getCrop() {
		return crop;
	}
	public int getMaxCrop() {
		return maxCrop;
	}
	@Override
	public Object clone() throws CloneNotSupportedException {
		ImageData clone = new ImageData(imageName, crop, maxCrop);
		for (Entry<Integer, NamedPolygon> poly : polygons.entrySet()) {
			clone.addPolygon((NamedPolygon) poly.getValue().clone(),poly.getKey());
		}
		return clone;
	}
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((crop == null) ? 0 : crop.hashCode());
		result = prime * result
				+ ((imageName == null) ? 0 : imageName.hashCode());
		result = prime * result + maxCrop;
		result = prime * result
				+ ((polygons == null) ? 0 : polygons.hashCode());
		return result;
	}
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		ImageData other = (ImageData) obj;
		if (crop != other.crop)
			return false;
		if (imageName == null) {
			if (other.imageName != null)
				return false;
		} else if (!imageName.equals(other.imageName))
			return false;
		if (maxCrop != other.maxCrop)
			return false;
		if (polygons == null) {
			if (other.polygons != null)
				return false;
		} else if (!polygons.equals(other.polygons))
			return false;
		return true;
	}
	
}
