package ch.sahits.game.graphic.image.model;

import java.awt.Polygon;
import java.util.Arrays;
/**
 * Version of the Ploygon that is identified by a name.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Mar 1, 2011
 *
 */
public class NamedPolygon extends Polygon implements Cloneable {
	private static final long serialVersionUID = -8375235009346591397L;
	private final String name;

	public NamedPolygon(String name) {
		super();
		this.name=name;
	}

	public NamedPolygon(int[] xpoints, int[] ypoints, int npoints,String name) {
		super(xpoints, ypoints, npoints);
		this.name=name;
	}

	public String getName() {
		return name;
	}
	
	public String toString(){
		StringBuilder sb = new StringBuilder();
		sb.append(name).append(" [");
		for (int i=0;i<npoints;i++){
			sb.append(xpoints[i]).append("x").append(ypoints[i]);
			if (i<npoints-1){
				sb.append(",");
			}
		}
		sb.append("]");
		return sb.toString();
	}

	@Override
	protected Object clone() throws CloneNotSupportedException {
		NamedPolygon clone = new NamedPolygon(name);
		for (int i=0;i<npoints;i++){
			clone.addPoint(xpoints[i], ypoints[i]);
		}
		return clone;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + npoints;
		result = prime * result + Arrays.hashCode(xpoints);
		result = prime * result + Arrays.hashCode(ypoints);
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (!(obj instanceof NamedPolygon))
			return false;
		NamedPolygon other = (NamedPolygon) obj;
		if (name == null) {
			if (other.name != null)
				return false;
		} else if (!name.equals(other.name))
			return false;
		if (npoints != other.npoints)
			return false;
		if (!Arrays.equals(xpoints, other.xpoints))
			return false;
		if (!Arrays.equals(ypoints, other.ypoints))
			return false;
		return true;
	}
//	/**
//	 * Returns <tt>true</tt> if the two specified arrays of ints are
//	 * <i>equal</i> to one another.  Two arrays are considered equal if both
//	 * arrays contain the same number of elements, and all corresponding pairs
//	 * of elements in the two arrays are equal.  In other words, two arrays
//	 * are equal if they contain the same elements in the same order.  Also,
//	 * two array references are considered equal if both are <tt>null</tt>.<p>
//	 *
//	 * @param a one array to be tested for equality
//	 * @param a2 the other array to be tested for equality
//	 * @return <tt>true</tt> if the two arrays are equal
//	 */
//	private static boolean equals(int[] a, int[] a2) {
//		if (a == a2)
//			return true;
//		if (a == null || a2 == null)
//			return false;
//
//		int length = a.length;
//		if (a2.length != length)
//			return false;
//
//		for (int i = 0; i < length; i++)
//			if (a[i] != a2[i])
//				return false;
//
//		return true;
//	}

	
}
